
godot_versions = {

# 1.1
    ':1.1::windows:32:'             : 'https://downloads.tuxfamily.org/godotengine/1.1/Godot_v1.1_stable_win32.exe.zip',
    ':1.1::windows:64:'             : 'https://downloads.tuxfamily.org/godotengine/1.1/Godot_v1.1_stable_win64.exe.zip',
    ':1.1::darwin:32:'              : 'https://downloads.tuxfamily.org/godotengine/1.1/Godot_v1.1_stable_osx32.zip',
    ':1.1::linux:32:'               : 'https://downloads.tuxfamily.org/godotengine/1.1/Godot_v1.1_stable_x11.32.zip',
    ':1.1::linux:64:'               : 'https://downloads.tuxfamily.org/godotengine/1.1/Godot_v1.1_stable_x11.64.zip',
# 2.0
    ':2.0::windows:32:'             : 'https://downloads.tuxfamily.org/godotengine/2.0/Godot_v2.0_stable_win32.exe.zip',
    ':2.0::windows:64:'             : 'https://downloads.tuxfamily.org/godotengine/2.0/Godot_v2.0_stable_win64.exe.zip',
    ':2.0::darwin:32:'              : 'https://downloads.tuxfamily.org/godotengine/2.0/Godot_v2.0_stable_osx32.zip',
    ':2.0::linux:32:'               : 'https://downloads.tuxfamily.org/godotengine/2.0/Godot_v2.0_stable_x11.32.zip',
    ':2.0::linux:64:'               : 'https://downloads.tuxfamily.org/godotengine/2.0/Godot_v2.0_stable_x11.64.zip',
# 2.0.1
    ':2.0.1::windows:32:'           : 'https://downloads.tuxfamily.org/godotengine/2.0.1/Godot_v2.0.1_stable_win32.exe.zip',
    ':2.0.1::windows:64:'           : 'https://downloads.tuxfamily.org/godotengine/2.0.1/Godot_v2.0.1_stable_win64.exe.zip',
    ':2.0.1::darwin:32:'            : 'https://downloads.tuxfamily.org/godotengine/2.0.1/Godot_v2.0.1_stable_osx32.zip',
    ':2.0.1::linux:32:'             : 'https://downloads.tuxfamily.org/godotengine/2.0.1/Godot_v2.0.1_stable_x11.32.zip',
    ':2.0.1::linux:64:'             : 'https://downloads.tuxfamily.org/godotengine/2.0.1/Godot_v2.0.1_stable_x11.64.zip',
# 2.0.2
    ':2.0.2::windows:32:'           : 'https://downloads.tuxfamily.org/godotengine/2.0.2/Godot_v2.0.2_stable_win32.exe.zip',
    ':2.0.2::windows:64:'           : 'https://downloads.tuxfamily.org/godotengine/2.0.2/Godot_v2.0.2_stable_win64.exe.zip',
    ':2.0.2::darwin:32:'            : 'https://downloads.tuxfamily.org/godotengine/2.0.2/Godot_v2.0.2_stable_osx32.zip',
    ':2.0.2::linux:32:'             : 'https://downloads.tuxfamily.org/godotengine/2.0.2/Godot_v2.0.2_stable_x11.32.zip',
    ':2.0.2::linux:64:'             : 'https://downloads.tuxfamily.org/godotengine/2.0.2/Godot_v2.0.2_stable_x11.64.zip',
# 2.0.3
    ':2.0.3::windows:32:'           : 'https://downloads.tuxfamily.org/godotengine/2.0.3/Godot_v2.0.3_stable_win32.exe.zip',
    ':2.0.3::windows:64:'           : 'https://downloads.tuxfamily.org/godotengine/2.0.3/Godot_v2.0.3_stable_win64.exe.zip',
    ':2.0.3::darwin:32:'            : 'https://downloads.tuxfamily.org/godotengine/2.0.3/Godot_v2.0.3_stable_osx32.zip',
    ':2.0.3::linux:32:'             : 'https://downloads.tuxfamily.org/godotengine/2.0.3/Godot_v2.0.3_stable_x11.32.zip',
    ':2.0.3::linux:64:'             : 'https://downloads.tuxfamily.org/godotengine/2.0.3/Godot_v2.0.3_stable_x11.64.zip',
# 2.0.4.1
    ':2.0.4.1::windows:32:'         : 'https://downloads.tuxfamily.org/godotengine/2.0.4.1/Godot_v2.0.4.1_stable_win32.exe.zip',
    ':2.0.4.1::windows:64:'         : 'https://downloads.tuxfamily.org/godotengine/2.0.4.1/Godot_v2.0.4.1_stable_win64.exe.zip',
    ':2.0.4.1::darwin:32:'          : 'https://downloads.tuxfamily.org/godotengine/2.0.4.1/Godot_v2.0.4.1_stable_osx.fat.zip',
    ':2.0.4.1::linux:32:'           : 'https://downloads.tuxfamily.org/godotengine/2.0.4.1/Godot_v2.0.4.1_stable_x11.32.zip',
    ':2.0.4.1::linux:64:'           : 'https://downloads.tuxfamily.org/godotengine/2.0.4.1/Godot_v2.0.4.1_stable_x11.64.zip',
# 2.1
    ':2.1::windows:32:'             : 'https://downloads.tuxfamily.org/godotengine/2.1/Godot_v2.1-stable_win32.exe.zip',
    ':2.1::windows:64:'             : 'https://downloads.tuxfamily.org/godotengine/2.1/Godot_v2.1-stable_win64.exe.zip',
    ':2.1::darwin:32:'              : 'https://downloads.tuxfamily.org/godotengine/2.1/Godot_v2.1-stable_osx.fat.zip',
    ':2.1::linux:32:'               : 'https://downloads.tuxfamily.org/godotengine/2.1/Godot_v2.1-stable_x11.32.zip',
    ':2.1::linux:64:'               : 'https://downloads.tuxfamily.org/godotengine/2.1/Godot_v2.1-stable_x11.64.zip',
# 2.1.1
    ':2.1.1::windows:32:'           : 'https://downloads.tuxfamily.org/godotengine/2.1.1/Godot_v2.1.1-stable_win32.exe.zip',
    ':2.1.1::windows:64:'           : 'https://downloads.tuxfamily.org/godotengine/2.1.1/Godot_v2.1.1-stable_win64.exe.zip',
    ':2.1.1::darwin:32:'            : 'https://downloads.tuxfamily.org/godotengine/2.1.1/Godot_v2.1.1-stable_osx.fat.zip',
    ':2.1.1::linux:32:'             : 'https://downloads.tuxfamily.org/godotengine/2.1.1/Godot_v2.1.1-stable_x11.32.zip',
    ':2.1.1::linux:64:'             : 'https://downloads.tuxfamily.org/godotengine/2.1.1/Godot_v2.1.1-stable_x11.64.zip',
# 2.1.2
    ':2.1.2::windows:32:'           : 'https://downloads.tuxfamily.org/godotengine/2.1.2/Godot_v2.1.2-stable_win32.exe.zip',
    ':2.1.2::windows:64:'           : 'https://downloads.tuxfamily.org/godotengine/2.1.2/Godot_v2.1.2-stable_win64.exe.zip',
    ':2.1.2::darwin:32:'            : 'https://downloads.tuxfamily.org/godotengine/2.1.2/Godot_v2.1.2-stable_osx.fat.zip',
    ':2.1.2::linux:32:'             : 'https://downloads.tuxfamily.org/godotengine/2.1.2/Godot_v2.1.2-stable_x11.32.zip',
    ':2.1.2::linux:64:'             : 'https://downloads.tuxfamily.org/godotengine/2.1.2/Godot_v2.1.2-stable_x11.64.zip',
# 2.1.3
    ':2.1.3::windows:32:'           : 'https://downloads.tuxfamily.org/godotengine/2.1.3/Godot_v2.1.3-stable_win32.exe.zip',
    ':2.1.3::windows:64:'           : 'https://downloads.tuxfamily.org/godotengine/2.1.3/Godot_v2.1.3-stable_win64.exe.zip',
    ':2.1.3::darwin:32:'            : 'https://downloads.tuxfamily.org/godotengine/2.1.3/Godot_v2.1.3-stable_osx.fat.zip',
    ':2.1.3::linux:32:'             : 'https://downloads.tuxfamily.org/godotengine/2.1.3/Godot_v2.1.3-stable_x11.32.zip',
    ':2.1.3::linux:64:'             : 'https://downloads.tuxfamily.org/godotengine/2.1.3/Godot_v2.1.3-stable_x11.64.zip',
# 2.1.4
    ':2.1.4::windows:32:'           : 'https://downloads.tuxfamily.org/godotengine/2.1.4/Godot_v2.1.4-stable_win32.exe.zip',
    ':2.1.4::windows:64:'           : 'https://downloads.tuxfamily.org/godotengine/2.1.4/Godot_v2.1.4-stable_win64.exe.zip',
    ':2.1.4::darwin:32:'            : 'https://downloads.tuxfamily.org/godotengine/2.1.4/Godot_v2.1.4-stable_osx.fat.zip',
    ':2.1.4::linux:32:'             : 'https://downloads.tuxfamily.org/godotengine/2.1.4/Godot_v2.1.4-stable_x11.32.zip',
    ':2.1.4::linux:64:'             : 'https://downloads.tuxfamily.org/godotengine/2.1.4/Godot_v2.1.4-stable_x11.64.zip',
# 2.1.5
    ':2.1.5::windows:32:'           : 'https://downloads.tuxfamily.org/godotengine/2.1.5/Godot_v2.1.5-stable_win32.exe.zip',
    ':2.1.5::windows:64:'           : 'https://downloads.tuxfamily.org/godotengine/2.1.5/Godot_v2.1.5-stable_win64.exe.zip',
    ':2.1.5::darwin:32:'            : 'https://downloads.tuxfamily.org/godotengine/2.1.5/Godot_v2.1.5-stable_osx.fat.zip',
    ':2.1.5::linux:32:'             : 'https://downloads.tuxfamily.org/godotengine/2.1.5/Godot_v2.1.5-stable_x11.32.zip',
    ':2.1.5::linux:64:'             : 'https://downloads.tuxfamily.org/godotengine/2.1.5/Godot_v2.1.5-stable_x11.64.zip',
# 2.1.6
    ':2.1.6::windows:32:'           : 'https://downloads.tuxfamily.org/godotengine/2.1.6/Godot_v2.1.6-stable_win32.exe.zip',
    ':2.1.6::windows:64:'           : 'https://downloads.tuxfamily.org/godotengine/2.1.6/Godot_v2.1.6-stable_win64.exe.zip',
    ':2.1.6::darwin:32:'            : 'https://downloads.tuxfamily.org/godotengine/2.1.6/Godot_v2.1.6-stable_osx.fat.zip',
    ':2.1.6::linux:32:'             : 'https://downloads.tuxfamily.org/godotengine/2.1.6/Godot_v2.1.6-stable_x11.32.zip',
    ':2.1.6::linux:64:'             : 'https://downloads.tuxfamily.org/godotengine/2.1.6/Godot_v2.1.5-stable_x11.64.zip',
# 3.0
    ':3.0::windows:32:'             : 'https://downloads.tuxfamily.org/godotengine/3.0/Godot_v3.0-stable_win32.exe.zip',
    ':3.0::windows:64:'             : 'https://downloads.tuxfamily.org/godotengine/3.0/Godot_v3.0-stable_win64.exe.zip',
    ':3.0::darwin:32:'              : 'https://downloads.tuxfamily.org/godotengine/3.0/Godot_v3.0-stable_osx.fat.zip',
    ':3.0::linux:32:'               : 'https://downloads.tuxfamily.org/godotengine/3.0/Godot_v3.0-stable_x11.32.zip',
    ':3.0::linux:64:'               : 'https://downloads.tuxfamily.org/godotengine/3.0/Godot_v3.0-stable_x11.64.zip',
    ':3.0::windows:32:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.0/mono/Godot_v3.0-stable_win32.exe.zip',
    ':3.0::windows:64:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.0/mono/Godot_v3.0-stable_win64.exe.zip',
    ':3.0::darwin:64:mono'          : 'https://downloads.tuxfamily.org/godotengine/3.0/mono/Godot_v3.0-stable_osx64.zip',
    ':3.0::linux:64:mono'           : 'https://downloads.tuxfamily.org/godotengine/3.0/mono/Godot_v3.0-stable_x11.32.zip',
# 3.0.1
    ':3.0.1::windows:32:'           : 'https://downloads.tuxfamily.org/godotengine/3.0.1/Godot_v3.0.1-stable_win32.exe.zip',
    ':3.0.1::windows:64:'           : 'https://downloads.tuxfamily.org/godotengine/3.0.1/Godot_v3.0.1-stable_win64.exe.zip',
    ':3.0.1::darwin:32:'            : 'https://downloads.tuxfamily.org/godotengine/3.0.1/Godot_v3.0.1-stable_osx.fat.zip',
    ':3.0.1::linux:32:'             : 'https://downloads.tuxfamily.org/godotengine/3.0.1/Godot_v3.0.1-stable_x11.32.zip',
    ':3.0.1::linux:64:'             : 'https://downloads.tuxfamily.org/godotengine/3.0.1/Godot_v3.0.1-stable_x11.64.zip',
    ':3.0.1::windows:32:mono'       : 'https://downloads.tuxfamily.org/godotengine/3.0.1/mono/Godot_v3.0.1-stable_win32.exe.zip',
    ':3.0.1::windows:64:mono'       : 'https://downloads.tuxfamily.org/godotengine/3.0.1/mono/Godot_v3.0.1-stable_win64.exe.zip',
    ':3.0.1::darwin:64:mono'        : 'https://downloads.tuxfamily.org/godotengine/3.0.1/mono/Godot_v3.0.1-stable_osx64.zip',
    ':3.0.1::linux:64:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.0.1/mono/Godot_v3.0.1-stable_x11.64.zip',
# 3.0.2
    ':3.0.2::windows:32:'           : 'https://downloads.tuxfamily.org/godotengine/3.0.2/Godot_v3.0.2-stable_win32.exe.zip',
    ':3.0.2::windows:64:'           : 'https://downloads.tuxfamily.org/godotengine/3.0.2/Godot_v3.0.2-stable_win64.exe.zip',
    ':3.0.2::darwin:32:'            : 'https://downloads.tuxfamily.org/godotengine/3.0.2/Godot_v3.0.2-stable_osx.fat.zip',
    ':3.0.2::linux:32:'             : 'https://downloads.tuxfamily.org/godotengine/3.0.2/Godot_v3.0.2-stable_x11.32.zip',
    ':3.0.2::linux:64:'             : 'https://downloads.tuxfamily.org/godotengine/3.0.2/Godot_v3.0.2-stable_x11.64.zip',
    ':3.0.2::windows:32:mono'       : 'https://downloads.tuxfamily.org/godotengine/3.0.2/mono/Godot_v3.0.2-stable_win32.exe.zip',
    ':3.0.2::windows:64:mono'       : 'https://downloads.tuxfamily.org/godotengine/3.0.2/mono/Godot_v3.0.2-stable_win64.exe.zip',
    ':3.0.2::darwin:64:mono'        : 'https://downloads.tuxfamily.org/godotengine/3.0.2/mono/Godot_v3.0.2-stable_osx64.zip',
    ':3.0.2::linux:64:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.0.2/mono/Godot_v3.0.2-stable_x11.64.zip',
# 3.0.3
    ':3.0.3::windows:32:'           : 'https://downloads.tuxfamily.org/godotengine/3.0.3/Godot_v3.0.3-stable_win32.exe.zip',
    ':3.0.3::windows:64:'           : 'https://downloads.tuxfamily.org/godotengine/3.0.3/Godot_v3.0.3-stable_win64.exe.zip',
    ':3.0.3::darwin:32:'            : 'https://downloads.tuxfamily.org/godotengine/3.0.3/Godot_v3.0.3-stable_osx.fat.zip',
    ':3.0.3::linux:32:'             : 'https://downloads.tuxfamily.org/godotengine/3.0.3/Godot_v3.0.3-stable_x11.32.zip',
    ':3.0.3::linux:64:'             : 'https://downloads.tuxfamily.org/godotengine/3.0.3/Godot_v3.0.3-stable_x11.64.zip',
    ':3.0.3::windows:32:mono'       : 'https://downloads.tuxfamily.org/godotengine/3.0.3/mono/Godot_v3.0.3-stable_win32.exe.zip',
    ':3.0.3::windows:64:mono'       : 'https://downloads.tuxfamily.org/godotengine/3.0.3/mono/Godot_v3.0.3-stable_win64.exe.zip',
    ':3.0.3::darwin:64:mono'        : 'https://downloads.tuxfamily.org/godotengine/3.0.3/mono/Godot_v3.0.3-stable_osx.fat.zip',
    ':3.0.3::linux:32:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.0.3/mono/Godot_v3.0.3-stable_x11.32.zip',
    ':3.0.3::linux:64:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.0.3/mono/Godot_v3.0.3-stable_x11.64.zip',
# 3.0.4
    ':3.0.4::windows:32:'           : 'https://downloads.tuxfamily.org/godotengine/3.0.4/Godot_v3.0.4-stable_win32.exe.zip',
    ':3.0.4::windows:64:'           : 'https://downloads.tuxfamily.org/godotengine/3.0.4/Godot_v3.0.4-stable_win64.exe.zip',
    ':3.0.4::darwin:32:'            : 'https://downloads.tuxfamily.org/godotengine/3.0.4/Godot_v3.0.4-stable_osx.fat.zip',
    ':3.0.4::linux:32:'             : 'https://downloads.tuxfamily.org/godotengine/3.0.4/Godot_v3.0.4-stable_x11.32.zip',
    ':3.0.4::linux:64:'             : 'https://downloads.tuxfamily.org/godotengine/3.0.4/Godot_v3.0.4-stable_x11.64.zip',
    ':3.0.4::windows:32:mono'       : 'https://downloads.tuxfamily.org/godotengine/3.0.4/mono/Godot_v3.0.4-stable_win32.exe.zip',
    ':3.0.4::windows:64:mono'       : 'https://downloads.tuxfamily.org/godotengine/3.0.4/mono/Godot_v3.0.4-stable_win64.exe.zip',
    ':3.0.4::darwin:64:mono'        : 'https://downloads.tuxfamily.org/godotengine/3.0.4/mono/Godot_v3.0.4-stable_osx.fat.zip',
    ':3.0.4::linux:32:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.0.4/mono/Godot_v3.0.4-stable_x11.32.zip',
    ':3.0.4::linux:64:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.0.4/mono/Godot_v3.0.4-stable_x11.64.zip',
# 3.0.5
    ':3.0.5::windows:32:'           : 'https://downloads.tuxfamily.org/godotengine/3.0.5/Godot_v3.0.5-stable_win32.exe.zip',
    ':3.0.5::windows:64:'           : 'https://downloads.tuxfamily.org/godotengine/3.0.5/Godot_v3.0.5-stable_win64.exe.zip',
    ':3.0.5::darwin:32:'            : 'https://downloads.tuxfamily.org/godotengine/3.0.5/Godot_v3.0.5-stable_osx.fat.zip',
    ':3.0.5::linux:32:'             : 'https://downloads.tuxfamily.org/godotengine/3.0.5/Godot_v3.0.5-stable_x11.32.zip',
    ':3.0.5::linux:64:'             : 'https://downloads.tuxfamily.org/godotengine/3.0.5/Godot_v3.0.5-stable_x11.64.zip',
    ':3.0.5::windows:32:mono'       : 'https://downloads.tuxfamily.org/godotengine/3.0.5/mono/Godot_v3.0.5-stable_win32.exe.zip',
    ':3.0.5::windows:64:mono'       : 'https://downloads.tuxfamily.org/godotengine/3.0.5/mono/Godot_v3.0.5-stable_win64.exe.zip',
    ':3.0.5::darwin:64:mono'        : 'https://downloads.tuxfamily.org/godotengine/3.0.5/mono/Godot_v3.0.5-stable_osx.fat.zip',
    ':3.0.5::linux:32:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.0.5/mono/Godot_v3.0.5-stable_x11.32.zip',
    ':3.0.5::linux:64:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.0.5/mono/Godot_v3.0.5-stable_x11.64.zip',
# 3.0.6
    ':3.0.6::windows:64:'           : 'https://downloads.tuxfamily.org/godotengine/3.0.6/Godot_v3.0.6-stable_win64.exe.zip',
    ':3.0.6::darwin:32:'            : 'https://downloads.tuxfamily.org/godotengine/3.0.6/Godot_v3.0.6-stable_osx.fat.zip',
    ':3.0.6::linux:32:'             : 'https://downloads.tuxfamily.org/godotengine/3.0.6/Godot_v3.0.6-stable_x11.32.zip',
    ':3.0.6::linux:64:'             : 'https://downloads.tuxfamily.org/godotengine/3.0.6/Godot_v3.0.6-stable_x11.64.zip',
    ':3.0.6::windows:32:mono'       : 'https://downloads.tuxfamily.org/godotengine/3.0.6/mono/Godot_v3.0.6-stable_win32.exe.zip',
    ':3.0.6::windows:64:mono'       : 'https://downloads.tuxfamily.org/godotengine/3.0.6/mono/Godot_v3.0.6-stable_win64.exe.zip',
    ':3.0.6::darwin:64:mono'        : 'https://downloads.tuxfamily.org/godotengine/3.0.6/mono/Godot_v3.0.6-stable_osx.fat.zip',
    ':3.0.6::linux:32:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.0.6/mono/Godot_v3.0.6-stable_x11.32.zip',
    ':3.0.6::linux:64:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.0.6/mono/Godot_v3.0.6-stable_x11.64.zip',
# 3.1
    ':3.1::windows:32:'             : 'https://downloads.tuxfamily.org/godotengine/3.1/Godot_v3.1-stable_win32.exe.zip',
    ':3.1::windows:64:'             : 'https://downloads.tuxfamily.org/godotengine/3.1/Godot_v3.1-stable_win64.exe.zip',
    ':3.1::darwin:64:'              : 'https://downloads.tuxfamily.org/godotengine/3.1/Godot_v3.1-stable_osx.64.zip',
    ':3.1::linux:32:'               : 'https://downloads.tuxfamily.org/godotengine/3.1/Godot_v3.1-stable_x11.32.zip',
    ':3.1::linux:64:'               : 'https://downloads.tuxfamily.org/godotengine/3.1/Godot_v3.1-stable_x11.64.zip',
    ':3.1::windows:32:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.1/mono/Godot_v3.1-stable_win32.exe.zip',
    ':3.1::windows:64:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.1/mono/Godot_v3.1-stable_win64.exe.zip',
    ':3.1::darwin:64:mono'          : 'https://downloads.tuxfamily.org/godotengine/3.1/mono/Godot_v3.1-stable_osx.64.zip',
    ':3.1::linux:32:mono'           : 'https://downloads.tuxfamily.org/godotengine/3.1/mono/Godot_v3.1-stable_x11.32.zip',
    ':3.1::linux:64:mono'           : 'https://downloads.tuxfamily.org/godotengine/3.1/mono/Godot_v3.1-stable_x11.64.zip',
# 3.1.1
    ':3.1.1::windows:32:'           : 'https://downloads.tuxfamily.org/godotengine/3.1.1/Godot_v3.1.1-stable_win32.exe.zip',
    ':3.1.1::windows:64:'           : 'https://downloads.tuxfamily.org/godotengine/3.1.1/Godot_v3.1.1-stable_win64.exe.zip',
    ':3.1.1::darwin:64:'            : 'https://downloads.tuxfamily.org/godotengine/3.1.1/Godot_v3.1.1-stable_osx.64.zip',
    ':3.1.1::linux:32:'             : 'https://downloads.tuxfamily.org/godotengine/3.1.1/Godot_v3.1.1-stable_x11.32.zip',
    ':3.1.1::linux:64:'             : 'https://downloads.tuxfamily.org/godotengine/3.1.1/Godot_v3.1.1-stable_x11.64.zip',
    ':3.1.1::windows:32:mono'       : 'https://downloads.tuxfamily.org/godotengine/3.1.1/mono/Godot_v3.1.1-stable_win32.exe.zip',
    ':3.1.1::windows:64:mono'       : 'https://downloads.tuxfamily.org/godotengine/3.1.1/mono/Godot_v3.1.1-stable_win64.exe.zip',
    ':3.1.1::darwin:64:mono'        : 'https://downloads.tuxfamily.org/godotengine/3.1.1/mono/Godot_v3.1.1-stable_osx.64.zip',
    ':3.1.1::linux:32:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.1.1/mono/Godot_v3.1.1-stable_x11.32.zip',
    ':3.1.1::linux:64:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.1.1/mono/Godot_v3.1.1-stable_x11.64.zip',
# 3.2
    ':3.1.2::windows:32:'           : 'https://downloads.tuxfamily.org/godotengine/3.1.2/Godot_v3.1.2-stable_win32.exe.zip',
    ':3.1.2::windows:64:'           : 'https://downloads.tuxfamily.org/godotengine/3.1.2/Godot_v3.1.2-stable_win64.exe.zip',
    ':3.1.2::darwin:64:'            : 'https://downloads.tuxfamily.org/godotengine/3.1.2/Godot_v3.1.2-stable_osx.64.zip',
    ':3.1.2::linux:32:'             : 'https://downloads.tuxfamily.org/godotengine/3.1.2/Godot_v3.1.2-stable_x11.32.zip',
    ':3.1.2::linux:64:'             : 'https://downloads.tuxfamily.org/godotengine/3.1.2/Godot_v3.1.2-stable_x11.64.zip',
    ':3.1.2::windows:32:mono'       : 'https://downloads.tuxfamily.org/godotengine/3.1.2/mono/Godot_v3.1.2-stable_win32.exe.zip',
    ':3.1.2::windows:64:mono'       : 'https://downloads.tuxfamily.org/godotengine/3.1.2/mono/Godot_v3.1.2-stable_win64.exe.zip',
    ':3.1.2::darwin:64:mono'        : 'https://downloads.tuxfamily.org/godotengine/3.1.2/mono/Godot_v3.1.2-stable_osx.64.zip',
    ':3.1.2::linux:32:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.1.2/mono/Godot_v3.1.2-stable_x11.32.zip',
    ':3.1.2::linux:64:mono'              : 'https://downloads.tuxfamily.org/godotengine/3.1.2/mono/Godot_v3.1.2-stable_x11.64.zip',
# 3.2
    ':3.2::windows:32:'             : 'https://downloads.tuxfamily.org/godotengine/3.2/Godot_v3.2-stable_win32.exe.zip',
    ':3.2::windows:64:'             : 'https://downloads.tuxfamily.org/godotengine/3.2/Godot_v3.2-stable_win64.exe.zip',
    ':3.2::darwin:64:'              : 'https://downloads.tuxfamily.org/godotengine/3.2/Godot_v3.2-stable_osx.64.zip',
    ':3.2::linux:32:'               : 'https://downloads.tuxfamily.org/godotengine/3.2/Godot_v3.2-stable_x11.32.zip',
    ':3.2::linux:64:'               : 'https://downloads.tuxfamily.org/godotengine/3.2/Godot_v3.2-stable_x11.64.zip',
    ':3.2::windows:32:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.2/mono/Godot_v3.2-stable_win32.exe.zip',
    ':3.2::windows:64:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.2/mono/Godot_v3.2-stable_win64.exe.zip',
    ':3.2::darwin:64:mono'          : 'https://downloads.tuxfamily.org/godotengine/3.2/mono/Godot_v3.2-stable_osx.64.zip',
    ':3.2::linux:32:mono'           : 'https://downloads.tuxfamily.org/godotengine/3.2/mono/Godot_v3.2-stable_x11.32.zip',
    ':3.2::linux:64:mono'           : 'https://downloads.tuxfamily.org/godotengine/3.2/mono/Godot_v3.2-stable_x11.64.zip',
# 3.2.1
    ':3.2.1::windows:32:'           : 'https://downloads.tuxfamily.org/godotengine/3.2.1/Godot_v3.2.1-stable_win32.exe.zip',
    ':3.2.1::windows:64:'           : 'https://downloads.tuxfamily.org/godotengine/3.2.1/Godot_v3.2.1-stable_win64.exe.zip',
    ':3.2.1::darwin:64:'            : 'https://downloads.tuxfamily.org/godotengine/3.2.1/Godot_v3.2.1-stable_osx.64.zip',
    ':3.2.1::linux:32:'             : 'https://downloads.tuxfamily.org/godotengine/3.2.1/Godot_v3.2.1-stable_x11.32.zip',
    ':3.2.1::linux:64:'             : 'https://downloads.tuxfamily.org/godotengine/3.2.1/Godot_v3.2.1-stable_x11.64.zip',
    ':3.2.1::windows:32:mono'       : 'https://downloads.tuxfamily.org/godotengine/3.2.1/mono/Godot_v3.2.1-stable_win32.exe.zip',
    ':3.2.1::windows:64:mono'       : 'https://downloads.tuxfamily.org/godotengine/3.2.1/mono/Godot_v3.2.1-stable_win64.exe.zip',
    ':3.2.1::darwin:64:mono'        : 'https://downloads.tuxfamily.org/godotengine/3.2.1/mono/Godot_v3.2.1-stable_osx.64.zip',
    ':3.2.1::linux:32:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.2.1/mono/Godot_v3.2.1-stable_x11.32.zip',
    ':3.2.1::linux:64:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.2.1/mono/Godot_v3.2.1-stable_x11.64.zip',
# 3.2.2
    ':3.2.2::windows:32:'           : 'https://downloads.tuxfamily.org/godotengine/3.2.2/Godot_v3.2.2-stable_win32.exe.zip',
    ':3.2.2::windows:64:'           : 'https://downloads.tuxfamily.org/godotengine/3.2.2/Godot_v3.2.2-stable_win64.exe.zip',
    ':3.2.2::darwin:64:'            : 'https://downloads.tuxfamily.org/godotengine/3.2.2/Godot_v3.2.2-stable_osx.64.zip',
    ':3.2.2::linux:32:'             : 'https://downloads.tuxfamily.org/godotengine/3.2.2/Godot_v3.2.2-stable_x11.32.zip',
    ':3.2.2::linux:64:'             : 'https://downloads.tuxfamily.org/godotengine/3.2.2/Godot_v3.2.2-stable_x11.64.zip',
    ':3.2.2::windows:32:mono'       : 'https://downloads.tuxfamily.org/godotengine/3.2.2/mono/Godot_v3.2.2-stable_win32.exe.zip',
    ':3.2.2::windows:64:mono'       : 'https://downloads.tuxfamily.org/godotengine/3.2.2/mono/Godot_v3.2.2-stable_win64.exe.zip',
    ':3.2.2::darwin:64:mono'        : 'https://downloads.tuxfamily.org/godotengine/3.2.2/mono/Godot_v3.2.2-stable_osx.64.zip',
    ':3.2.2::linux:32:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.2.2/mono/Godot_v3.2.2-stable_x11.32.zip',
    ':3.2.2::linux:64:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.2.2/mono/Godot_v3.2.2-stable_x11.64.zip',
# 3.2.3
    ':3.2.3::darwin:64:'            : 'https://downloads.tuxfamily.org/godotengine/3.2.3/Godot_v3.2.3-stable_osx.64.zip',
    ':3.2.3::linux:32:'             : 'https://downloads.tuxfamily.org/godotengine/3.2.3/Godot_v3.2.3-stable_x11.32.zip',
    ':3.2.3::linux:64:'             : 'https://downloads.tuxfamily.org/godotengine/3.2.3/Godot_v3.2.3-stable_x11.64.zip',
    ':3.2.3::windows:32:'           : 'https://downloads.tuxfamily.org/godotengine/3.2.3/Godot_v3.2.3-stable_win32.exe.zip',
    ':3.2.3::windows:64:'           : 'https://downloads.tuxfamily.org/godotengine/3.2.3/Godot_v3.2.3-stable_win64.exe.zip',
    ':3.2.3::darwin:64:mono'        : 'https://downloads.tuxfamily.org/godotengine/3.2.3/mono/Godot_v3.2.3-stable_mono_osx.64.zip',
    ':3.2.3::linux:32:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.2.3/mono/Godot_v3.2.3-stable_mono_x11_32.zip',
    ':3.2.3::linux:64:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.2.3/mono/Godot_v3.2.3-stable_mono_x11_64.zip',
    ':3.2.3::windows:32:mono'       : 'https://downloads.tuxfamily.org/godotengine/3.2.3/mono/Godot_v3.2.3-stable_mono_win32.zip',
    ':3.2.3::windows:64:mono'       : 'https://downloads.tuxfamily.org/godotengine/3.2.3/mono/Godot_v3.2.3-stable_mono_win64.zip',
# 3.3
    ':3.3::darwin::'                : 'https://downloads.tuxfamily.org/godotengine/3.3/Godot_v3.3-stable_osx.universal.zip',
    ':3.3::linux:32:'               : 'https://downloads.tuxfamily.org/godotengine/3.3/Godot_v3.3-stable_x11.32.zip',
    ':3.3::linux:64:'               : 'https://downloads.tuxfamily.org/godotengine/3.3/Godot_v3.3-stable_x11.64.zip',
    ':3.3::windows:64:'             : 'https://downloads.tuxfamily.org/godotengine/3.3/Godot_v3.3-stable_win64.exe.zip',
    ':3.3::windows:32:'             : 'https://downloads.tuxfamily.org/godotengine/3.3/Godot_v3.3-stable_win32.exe.zip',
    ':3.3::darwin::mono'            : 'https://downloads.tuxfamily.org/godotengine/3.3/mono/Godot_v3.3-stable_mono_osx.64.zip',
    ':3.3::linux:32:mono'           : 'https://downloads.tuxfamily.org/godotengine/3.3/mono/Godot_v3.3-stable_mono_x11_32.zip',
    ':3.3::linux:64:mono'           : 'https://downloads.tuxfamily.org/godotengine/3.3/mono/Godot_v3.3-stable_mono_x11_64.zip',
    ':3.3::windows:64:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.3/mono/Godot_v3.3-stable_mono_win32.zip',
    ':3.3::windows:32:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.3/mono/Godot_v3.3-stable_mono_win64.zip',
# 3.3.1
    ':3.3.1::darwin::'                : 'https://downloads.tuxfamily.org/godotengine/3.3.1/Godot_v3.3.1-stable_osx.universal.zip',
    ':3.3.1::linux:32:'               : 'https://downloads.tuxfamily.org/godotengine/3.3.1/Godot_v3.3.1-stable_x11.32.zip',
    ':3.3.1::linux:64:'               : 'https://downloads.tuxfamily.org/godotengine/3.3.1/Godot_v3.3.1-stable_x11.64.zip',
    ':3.3.1::windows:64:'             : 'https://downloads.tuxfamily.org/godotengine/3.3.1/Godot_v3.3.1-stable_win64.exe.zip',
    ':3.3.1::windows:32:'             : 'https://downloads.tuxfamily.org/godotengine/3.3.1/Godot_v3.3.1-stable_win32.exe.zip',
    ':3.3.1::darwin::mono'            : 'https://downloads.tuxfamily.org/godotengine/3.3.1/mono/Godot_v3.3.1-stable_mono_osx.64.zip',
    ':3.3.1::linux:32:mono'           : 'https://downloads.tuxfamily.org/godotengine/3.3.1/mono/Godot_v3.3.1-stable_mono_x11_32.zip',
    ':3.3.1::linux:64:mono'           : 'https://downloads.tuxfamily.org/godotengine/3.3.1/mono/Godot_v3.3.1-stable_mono_x11_64.zip',
    ':3.3.1::windows:64:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.3.1/mono/Godot_v3.3.1-stable_mono_win32.zip',
    ':3.3.1::windows:32:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.3.1/mono/Godot_v3.3.1-stable_mono_win64.zip',
# 3.3.2
    ':3.3.2::darwin::'                : 'https://downloads.tuxfamily.org/godotengine/3.3.2/Godot_v3.3.2-stable_osx.universal.zip',
    ':3.3.2::linux:32:'               : 'https://downloads.tuxfamily.org/godotengine/3.3.2/Godot_v3.3.2-stable_x11.32.zip',
    ':3.3.2::linux:64:'               : 'https://downloads.tuxfamily.org/godotengine/3.3.2/Godot_v3.3.2-stable_x11.64.zip',
    ':3.3.2::windows:64:'             : 'https://downloads.tuxfamily.org/godotengine/3.3.2/Godot_v3.3.2-stable_win64.exe.zip',
    ':3.3.2::windows:32:'             : 'https://downloads.tuxfamily.org/godotengine/3.3.2/Godot_v3.3.2-stable_win32.exe.zip',
    ':3.3.2::darwin::mono'            : 'https://downloads.tuxfamily.org/godotengine/3.3.2/mono/Godot_v3.3.2-stable_mono_osx.64.zip',
    ':3.3.2::linux:32:mono'           : 'https://downloads.tuxfamily.org/godotengine/3.3.2/mono/Godot_v3.3.2-stable_mono_x11_32.zip',
    ':3.3.2::linux:64:mono'           : 'https://downloads.tuxfamily.org/godotengine/3.3.2/mono/Godot_v3.3.2-stable_mono_x11_64.zip',
    ':3.3.2::windows:64:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.3.2/mono/Godot_v3.3.2-stable_mono_win32.zip',
    ':3.3.2::windows:32:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.3.2/mono/Godot_v3.3.2-stable_mono_win64.zip',
# 3.3.3
    ':3.3.3::darwin::'             : 'https://downloads.tuxfamily.org/godotengine/3.3.3/Godot_v3.3.3-stable_osx.universal.zip',
    ':3.3.3::linux:32:'            : 'https://downloads.tuxfamily.org/godotengine/3.3.3/Godot_v3.3.3-stable_x11.32.zip',
    ':3.3.3::linux:64:'            : 'https://downloads.tuxfamily.org/godotengine/3.3.3/Godot_v3.3.3-stable_x11.64.zip',
    ':3.3.3::windows:64:'          : 'https://downloads.tuxfamily.org/godotengine/3.3.3/Godot_v3.3.3-stable_win64.exe.zip',
    ':3.3.3::windows:32:'          : 'https://downloads.tuxfamily.org/godotengine/3.3.3/Godot_v3.3.3-stable_win32.exe.zip',
    ':3.3.3::darwin::mono'         : 'https://downloads.tuxfamily.org/godotengine/3.3.3/mono/Godot_v3.3.3-stable_mono_osx.64.zip',
    ':3.3.3::linux:32:mono'        : 'https://downloads.tuxfamily.org/godotengine/3.3.3/mono/Godot_v3.3.3-stable_mono_x11_32.zip',
    ':3.3.3::linux:64:mono'        : 'https://downloads.tuxfamily.org/godotengine/3.3.3/mono/Godot_v3.3.3-stable_mono_x11_64.zip',
    ':3.3.3::windows:64:mono'      : 'https://downloads.tuxfamily.org/godotengine/3.3.3/mono/Godot_v3.3.3-stable_mono_win32.zip',
    ':3.3.3::windows:32:mono'      : 'https://downloads.tuxfamily.org/godotengine/3.3.3/mono/Godot_v3.3.3-stable_mono_win64.zip',
# 3.3.4
    ':3.3.4::darwin::'             : 'https://downloads.tuxfamily.org/godotengine/3.3.4/Godot_v3.3.4-stable_osx.universal.zip',
    ':3.3.4::linux:32:'            : 'https://downloads.tuxfamily.org/godotengine/3.3.4/Godot_v3.3.4-stable_x11.32.zip',
    ':3.3.4::linux:64:'            : 'https://downloads.tuxfamily.org/godotengine/3.3.4/Godot_v3.3.4-stable_x11.64.zip',
    ':3.3.4::windows:64:'          : 'https://downloads.tuxfamily.org/godotengine/3.3.4/Godot_v3.3.4-stable_win64.exe.zip',
    ':3.3.4::windows:32:'          : 'https://downloads.tuxfamily.org/godotengine/3.3.4/Godot_v3.3.4-stable_win32.exe.zip',
    ':3.3.4::darwin::mono'         : 'https://downloads.tuxfamily.org/godotengine/3.3.4/mono/Godot_v3.3.4-stable_mono_osx.64.zip',
    ':3.3.4::linux:32:mono'        : 'https://downloads.tuxfamily.org/godotengine/3.3.4/mono/Godot_v3.3.4-stable_mono_x11_32.zip',
    ':3.3.4::linux:64:mono'        : 'https://downloads.tuxfamily.org/godotengine/3.3.4/mono/Godot_v3.3.4-stable_mono_x11_64.zip',
    ':3.3.4::windows:64:mono'      : 'https://downloads.tuxfamily.org/godotengine/3.3.4/mono/Godot_v3.3.4-stable_mono_win32.zip',
    ':3.3.4::windows:32:mono'      : 'https://downloads.tuxfamily.org/godotengine/3.3.4/mono/Godot_v3.3.4-stable_mono_win64.zip',
# 3.4
    ':3.4::darwin::'                : 'https://downloads.tuxfamily.org/godotengine/3.4/Godot_v3.4-stable_osx.universal.zip',
    ':3.4::linux:32:'               : 'https://downloads.tuxfamily.org/godotengine/3.4/Godot_v3.4-stable_x11.32.zip',
    ':3.4::linux:64:'               : 'https://downloads.tuxfamily.org/godotengine/3.4/Godot_v3.4-stable_x11.64.zip',
    ':3.4::windows:64:'             : 'https://downloads.tuxfamily.org/godotengine/3.4/Godot_v3.4-stable_win64.exe.zip',
    ':3.4::windows:32:'             : 'https://downloads.tuxfamily.org/godotengine/3.4/Godot_v3.4-stable_win32.exe.zip',
    ':3.4::darwin::mono'            : 'https://downloads.tuxfamily.org/godotengine/3.4/mono/Godot_v3.4-stable_mono_osx.64.zip',
    ':3.4::linux:32:mono'           : 'https://downloads.tuxfamily.org/godotengine/3.4/mono/Godot_v3.4-stable_mono_x11_32.zip',
    ':3.4::linux:64:mono'           : 'https://downloads.tuxfamily.org/godotengine/3.4/mono/Godot_v3.4-stable_mono_x11_64.zip',
    ':3.4::windows:64:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.4/mono/Godot_v3.4-stable_mono_win32.zip',
    ':3.4::windows:32:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.4/mono/Godot_v3.4-stable_mono_win64.zip',
# 3.4.1
    ':3.4.1::darwin::'           	: 'https://downloads.tuxfamily.org/godotengine/3.4.1/Godot_v3.4.1-stable_osx.universal.zip',
    ':3.4.1::linux:32:'               : 'https://downloads.tuxfamily.org/godotengine/3.4.1/Godot_v3.4.1-stable_x11.32.zip',
    ':3.4.1::linux:64:'               : 'https://downloads.tuxfamily.org/godotengine/3.4.1/Godot_v3.4.1-stable_x11.64.zip',
    ':3.4.1::windows:64:'             : 'https://downloads.tuxfamily.org/godotengine/3.4.1/Godot_v3.4.1-stable_win64.exe.zip',
    ':3.4.1::windows:32:'             : 'https://downloads.tuxfamily.org/godotengine/3.4.1/Godot_v3.4.1-stable_win32.exe.zip',
    ':3.4.1::darwin::mono'            : 'https://downloads.tuxfamily.org/godotengine/3.4.1/mono/Godot_v3.4.1-stable_mono_osx.64.zip',
    ':3.4.1::linux:32:mono'           : 'https://downloads.tuxfamily.org/godotengine/3.4.1/mono/Godot_v3.4.1-stable_mono_x11_32.zip',
    ':3.4.1::linux:64:mono'           : 'https://downloads.tuxfamily.org/godotengine/3.4.1/mono/Godot_v3.4.1-stable_mono_x11_64.zip',
    ':3.4.1::windows:64:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.4.1/mono/Godot_v3.4.1-stable_mono_win32.zip',
    ':3.4.1::windows:32:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.4.1/mono/Godot_v3.4.1-stable_mono_win64.zip',
# 3.4.2
    ':3.4.2::darwin::'                : 'https://downloads.tuxfamily.org/godotengine/3.4.2/Godot_v3.4.2-stable_osx.universal.zip',
    ':3.4.2::linux:32:'               : 'https://downloads.tuxfamily.org/godotengine/3.4.2/Godot_v3.4.2-stable_x11.32.zip',
    ':3.4.2::linux:64:'               : 'https://downloads.tuxfamily.org/godotengine/3.4.2/Godot_v3.4.2-stable_x11.64.zip',
    ':3.4.2::windows:64:'             : 'https://downloads.tuxfamily.org/godotengine/3.4.2/Godot_v3.4.2-stable_win64.exe.zip',
    ':3.4.2::windows:32:'             : 'https://downloads.tuxfamily.org/godotengine/3.4.2/Godot_v3.4.2-stable_win32.exe.zip',
    ':3.4.2::darwin::mono'            : 'https://downloads.tuxfamily.org/godotengine/3.4.2/mono/Godot_v3.4.2-stable_mono_osx.universal.zip',
    ':3.4.2::linux:32:mono'           : 'https://downloads.tuxfamily.org/godotengine/3.4.2/mono/Godot_v3.4.2-stable_mono_x11_32.zip',
    ':3.4.2::linux:64:mono'           : 'https://downloads.tuxfamily.org/godotengine/3.4.2/mono/Godot_v3.4.2-stable_mono_x11_64.zip',
    ':3.4.2::windows:64:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.4.2/mono/Godot_v3.4.2-stable_mono_win32.zip',
    ':3.4.2::windows:32:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.4.2/mono/Godot_v3.4.2-stable_mono_win64.zip',
# 3.4.3
    ':3.4.3::darwin::'                : 'https://downloads.tuxfamily.org/godotengine/3.4.3/Godot_v3.4.3-stable_osx.universal.zip',
    ':3.4.3::linux:32:'               : 'https://downloads.tuxfamily.org/godotengine/3.4.3/Godot_v3.4.3-stable_x11.32.zip',
    ':3.4.3::linux:64:'               : 'https://downloads.tuxfamily.org/godotengine/3.4.3/Godot_v3.4.3-stable_x11.64.zip',
    ':3.4.3::windows:64:'             : 'https://downloads.tuxfamily.org/godotengine/3.4.3/Godot_v3.4.3-stable_win64.exe.zip',
    ':3.4.3::windows:32:'             : 'https://downloads.tuxfamily.org/godotengine/3.4.3/Godot_v3.4.3-stable_win32.exe.zip',
    ':3.4.3::darwin::mono'            : 'https://downloads.tuxfamily.org/godotengine/3.4.3/mono/Godot_v3.4.3-stable_mono_osx.universal.zip',
    ':3.4.3::linux:32:mono'           : 'https://downloads.tuxfamily.org/godotengine/3.4.3/mono/Godot_v3.4.3-stable_mono_x11_32.zip',
    ':3.4.3::linux:64:mono'           : 'https://downloads.tuxfamily.org/godotengine/3.4.3/mono/Godot_v3.4.3-stable_mono_x11_64.zip',
    ':3.4.3::windows:64:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.4.3/mono/Godot_v3.4.3-stable_mono_win32.zip',
    ':3.4.3::windows:32:mono'         : 'https://downloads.tuxfamily.org/godotengine/3.4.3/mono/Godot_v3.4.3-stable_mono_win64.zip',
# 3.4.4
    ':3.4.4::darwin::'                  : 'https://downloads.tuxfamily.org/godotengine/3.4.4/Godot_v3.4.4-stable_osx.universal.zip',
    ':3.4.4::linux:32:'                 : 'https://downloads.tuxfamily.org/godotengine/3.4.4/Godot_v3.4.4-stable_x11.32.zip',
    ':3.4.4::linux:64:'                 : 'https://downloads.tuxfamily.org/godotengine/3.4.4/Godot_v3.4.4-stable_x11.64.zip',
    ':3.4.4::windows:64:'               : 'https://downloads.tuxfamily.org/godotengine/3.4.4/Godot_v3.4.4-stable_win64.exe.zip',
    ':3.4.4::windows:32:'               : 'https://downloads.tuxfamily.org/godotengine/3.4.4/Godot_v3.4.4-stable_win32.exe.zip',
    ':3.4.4::darwin::mono'              : 'https://downloads.tuxfamily.org/godotengine/3.4.4/mono/Godot_v3.4.4-stable_mono_osx.universal.zip',
    ':3.4.4::linux:32:mono'             : 'https://downloads.tuxfamily.org/godotengine/3.4.4/mono/Godot_v3.4.4-stable_mono_x11_32.zip',
    ':3.4.4::linux:64:mono'             : 'https://downloads.tuxfamily.org/godotengine/3.4.4/mono/Godot_v3.4.4-stable_mono_x11_64.zip',
    ':3.4.4::windows:64:mono'           : 'https://downloads.tuxfamily.org/godotengine/3.4.4/mono/Godot_v3.4.4-stable_mono_win32.zip',
    ':3.4.4::windows:32:mono'           : 'https://downloads.tuxfamily.org/godotengine/3.4.4/mono/Godot_v3.4.4-stable_mono_win64.zip',
# 3.4.5
    ':3.4.5::darwin::'                  : 'https://downloads.tuxfamily.org/godotengine/3.4.5/rc1/Godot_v3.4.5-rc1_osx.universal.zip',
    ':3.4.5::linux:32:'                 : 'https://downloads.tuxfamily.org/godotengine/3.4.5/rc1/Godot_v3.4.5-rc1_x11.32.zip',
    ':3.4.5::linux:64:'                 : 'https://downloads.tuxfamily.org/godotengine/3.4.5/rc1/Godot_v3.4.5-rc1_x11.64.zip',
    ':3.4.5::windows:64:'               : 'https://downloads.tuxfamily.org/godotengine/3.4.5/rc1/Godot_v3.4.5-rc1_win64.exe.zip',
    ':3.4.5::windows:32:'               : 'https://downloads.tuxfamily.org/godotengine/3.4.5/rc1/Godot_v3.4.5-rc1_win32.exe.zip',
    ':3.4.5::darwin::mono'              : 'https://downloads.tuxfamily.org/godotengine/3.4.5/rc1/mono/Godot_v3.4.5-rc1_mono_osx.universal.zip',
    ':3.4.5::linux:32:mono'             : 'https://downloads.tuxfamily.org/godotengine/3.4.5/rc1/mono/Godot_v3.4.5-rc1_mono_x11_32.zip',
    ':3.4.5::linux:64:mono'             : 'https://downloads.tuxfamily.org/godotengine/3.4.5/rc1/mono/Godot_v3.4.5-rc1_mono_x11_64.zip',
    ':3.4.5::windows:64:mono'           : 'https://downloads.tuxfamily.org/godotengine/3.4.5/rc1/mono/Godot_v3.4.5-rc1_mono_win32.zip',
    ':3.4.5::windows:32:mono'           : 'https://downloads.tuxfamily.org/godotengine/3.4.5/rc1/mono/Godot_v3.4.5-rc1_mono_win64.zip',
# 3.5
    ':3.5::darwin::'                    : 'https://downloads.tuxfamily.org/godotengine/3.5/Godot_v3.5-stable_osx.universal.zip',
    ':3.5::linux:32:'                   : 'https://downloads.tuxfamily.org/godotengine/3.5/Godot_v3.5-stable_x11.32.zip',
    ':3.5::linux:64:'                   : 'https://downloads.tuxfamily.org/godotengine/3.5/Godot_v3.5-stable_x11.64.zip',
    ':3.5::windows:64:'                 : 'https://downloads.tuxfamily.org/godotengine/3.5/Godot_v3.5-stable_win64.exe.zip',
    ':3.5::windows:32:'                 : 'https://downloads.tuxfamily.org/godotengine/3.5/Godot_v3.5-stable_win32.exe.zip',
    ':3.5::darwin::mono'                : 'https://downloads.tuxfamily.org/godotengine/3.5/mono/Godot_v3.5-stable_mono_osx.universal.zip',
    ':3.5::linux:32:mono'               : 'https://downloads.tuxfamily.org/godotengine/3.5/mono/Godot_v3.5-stable_mono_x11_32.zip',
    ':3.5::linux:64:mono'               : 'https://downloads.tuxfamily.org/godotengine/3.5/mono/Godot_v3.5-stable_mono_x11_64.zip',
    ':3.5::windows:64:mono'             : 'https://downloads.tuxfamily.org/godotengine/3.5/mono/Godot_v3.5-stable_mono_win32.zip',
    ':3.5::windows:32:mono'             : 'https://downloads.tuxfamily.org/godotengine/3.5/mono/Godot_v3.5-stable_mono_win64.zip',
# 3.5.1
    ':3.5.1::darwin::'                  : 'https://downloads.tuxfamily.org/godotengine/3.5.1/Godot_v3.5.1-stable_osx.universal.zip',
    ':3.5.1::linux:32:'                 : 'https://downloads.tuxfamily.org/godotengine/3.5.1/Godot_v3.5.1-stable_x11.32.zip',
    ':3.5.1::linux:64:'                 : 'https://downloads.tuxfamily.org/godotengine/3.5.1/Godot_v3.5.1-stable_x11.64.zip',
    ':3.5.1::windows:64:'               : 'https://downloads.tuxfamily.org/godotengine/3.5.1/Godot_v3.5.1-stable_win64.exe.zip',
    ':3.5.1::windows:32:'               : 'https://downloads.tuxfamily.org/godotengine/3.5.1/Godot_v3.5.1-stable_win32.exe.zip',
    ':3.5.1::darwin::mono'              : 'https://downloads.tuxfamily.org/godotengine/3.5/mono/Godot_v3.5.1-stable_mono_osx.universal.zip',
    ':3.5.1::linux:32:mono'             : 'https://downloads.tuxfamily.org/godotengine/3.5/mono/Godot_v3.5.1-stable_mono_x11_32.zip',
    ':3.5.1::linux:64:mono'             : 'https://downloads.tuxfamily.org/godotengine/3.5/mono/Godot_v3.5.1-stable_mono_x11_64.zip',
    ':3.5.1::windows:64:mono'           : 'https://downloads.tuxfamily.org/godotengine/3.5/mono/Godot_v3.5.1-stable_mono_win32.zip',
    ':3.5.1::windows:32:mono'           : 'https://downloads.tuxfamily.org/godotengine/3.5/mono/Godot_v3.5.1-stable_mono_win64.zip',
# 4.0
    ':4.0::darwin::'                	: 'https://downloads.tuxfamily.org/godotengine/4.0/beta1/Godot_v4.0-beta1_osx.universal.zip',
    ':4.0::linux:32:'               	: 'https://downloads.tuxfamily.org/godotengine/4.0/beta1/Godot_v4.0-beta1_x11.32.zip',
    ':4.0::linux:64:'               	: 'https://downloads.tuxfamily.org/godotengine/4.0/beta1/Godot_v4.0-beta1_x11.64.zip',
    ':4.0::windows:64:'             	: 'https://downloads.tuxfamily.org/godotengine/4.0/beta1/Godot_v4.0-beta1_win64.exe.zip',
    ':4.0::windows:32:'             	: 'https://downloads.tuxfamily.org/godotengine/4.0/beta1/Godot_v4.0-beta1_win32.exe.zip',
    ':4.0::darwin::mono'              	: 'https://downloads.tuxfamily.org/godotengine/4.0/beta1/mono/Godot_v4.0-beta1_mono_osx.universal.zip',
    ':4.0::linux:32:mono'             	: 'https://downloads.tuxfamily.org/godotengine/4.0/beta1/mono/Godot_v4.0-beta1_mono_x11_32.zip',
    ':4.0::linux:64:mono'             	: 'https://downloads.tuxfamily.org/godotengine/4.0/beta1/mono/Godot_v4.0-beta1_mono_x11_64.zip',
    ':4.0::windows:64:mono'           	: 'https://downloads.tuxfamily.org/godotengine/4.0/beta1/mono/Godot_v4.0-beta1_mono_win32.zip',
    ':4.0::windows:32:mono'           	: 'https://downloads.tuxfamily.org/godotengine/4.0/beta1/mono/Godot_v4.0-beta1_mono_win64.zip',
}
